#include <stm32f10x_lib.h>
#include "AdcDriver.h"

//==============================================================================
// A simple delay for about half a second or so.
// Timing isn't exact or important.
//==============================================================================
void delay ()
{
	static int delaytime = 150000;
	int i;
	for ( i = 1; i < delaytime; ++i)
	{
		int j = 1;
		j = j+1;
	}
}

//==============================================================================
// configuration changes to use the buzzer
//==============================================================================
void configBuzzer()
{
	GPIOC->CRL &= 0xF0FFFFFF;
	GPIOC->CRL |= 0x03000000;

	GPIOC->CRH &= 0xFFFFFFF0;
	GPIOC->CRH |= 0x00000003;
	
	GPIOC->ODR |=  0x00000040;
}

//==============================================================================
// revert changes to use the buzzer
//==============================================================================
void unconfigBuzzer()
{
	GPIOC->CRL &= 0xF0FFFFFF;
	GPIOC->CRL |= 0x04000000;

	GPIOC->CRH &= 0xFFFFFFF0;
	GPIOC->CRH |= 0x00000004;


	GPIOC->ODR &= 0x0000001F;	
}

//==============================================================================
// run the buzzer test.
//==============================================================================
void testBuzzer()
{
	// the speaker sweet spot is 4Khz.
	int delayTime = 150; // 100 ;
	int i, j, k;

	configBuzzer();

	for ( k = 1; k < 100; ++k)
	{		
		for ( j = 1; j < 1000; ++j)		
		{
			for ( i = 1; i < delayTime; ++i)
			{		
				int j = 1;
				j = j+1;
				
	
			}
			GPIOC->ODR ^= 1 << 6;
			GPIOC->ODR ^= 1 << 8;
	    }
		--delayTime;
	}

	unconfigBuzzer();
}

//==============================================================================
// configuration changes to use the display
//==============================================================================
void configDisplay(int disableDebug)
{
	//PORT A0-15, FOR DISPLAY COL 1-16
	GPIOA->CRH =  0X33333333;
	GPIOA->CRL =  0X33333333;	

	//PORTB B2-B9, DISPLAY ROW	, B0 =zero det	   ,B1 = reserved
	GPIOB->CRL &= 0x000000FF;
	GPIOB->CRL |= 0x33333300;
	
	GPIOB->CRH &= 0xFFFFFF00;
	GPIOB->CRH |= 0x00000033;

	// disable the Software debug lines that clog up some of GPIO A and B
	if ( disableDebug != 0 )
	{
		AFIO->MAPR =  0x04000000;
	}
}

//==============================================================================
// revert changes to use the display
//==============================================================================
void unconfigDisplay()
{
	//PORT A0-15, FOR DISPLAY COL 1-16
	GPIOA->CRH =  0X44444444;
	GPIOA->CRL =  0X44444444;	

	//PORTB B2-B9, DISPLAY ROW	, B0 =zero det	   ,B1 = reserved
	GPIOB->CRL &= 0x000000FF;
	GPIOB->CRL |= 0x44444400;
	
	GPIOB->CRH &= 0xFFFFFF00;
	GPIOB->CRH |= 0x00000044;

	AFIO->MAPR =  0x00000000;
}

//==============================================================================
// light each column, then row in sequence
//==============================================================================
void testDisplay()
{
	unsigned int trash = 0;
	int counter;

	configDisplay(1);

    // walk left to right
	// turn on all rows
	GPIOB->ODR = 0x0000FFFF;
	
	// turn on column by column
	for (trash = 0xFFFE, counter = 0; counter < 16; ++counter )
	{
		GPIOA->ODR = trash;
		delay();
		trash <<=1;
		trash+=1;
    }

	// turn on row by row
	GPIOA->ODR = 0x00000000;
	for (trash = 0x0004, counter = 0; counter < 8; ++counter )
	{
		GPIOB->ODR = trash;
		delay();
		trash <<=1;
    }

	unconfigDisplay();
}

//==============================================================================
// turn the light bulb on and off
//==============================================================================
void testTriac()
{
	// tests the Triac/Optocoupler
	GPIOC->ODR ^= 1 << 7;
	delay();
	delay();

	GPIOC->ODR ^= 1 << 7;
	delay();
	delay();
}

//==============================================================================
// read the light sensor, and use the display as a VU meter.
//==============================================================================
void lightSensorTest()
{
	unsigned short reading = 0;
	int displayColumn = 0;
	int displayDecode = 0;
	
	initLightSensor();

	// turn on the display for a visual output
	// but keep the software debug lines available
	configDisplay(0);

	// get a reading
	reading = getLightSensorReading();

	// scale it.
	reading -= 0x400;
	reading >>= 8;

	// display it.
	// turn on all rows
	GPIOB->ODR = 0x0000FFFF;
	displayDecode = 0xFFFE;
	for (displayColumn = 0; displayColumn < reading; displayColumn ++)
	{
		GPIOA->ODR = displayDecode;
		displayDecode <<= 1;
	}

	delay();

	deinitLightSensor();
}

